@@ -356,6 +356,10 @@ BatchExtractJob::BatchExtractJob(LoadJob *loadJob, const QString &destination, b
 void BatchExtractJob::doWork()
 {
     connect(m_loadJob, &KJob::result, this, &BatchExtractJob::slotLoadingFinished);
+    if (archiveInterface()->hasBatchExtractionProgress()) {
+        // progress() will be actually emitted by the LoadJob, but the archiveInterface() is the same.
+        connect(archiveInterface(), &ReadOnlyArchiveInterface::progress, this, &BatchExtractJob::slotLoadingProgress);
+    }
 
     // Forward LoadJob's signals.
     connect(m_loadJob, &Kerfuffle::Job::newEntry, this, &BatchExtractJob::newEntry);
@@ -363,6 +367,28 @@ void BatchExtractJob::doWork()
     m_loadJob->start();
 }
 
+bool BatchExtractJob::doKill()
+{
+    if (m_step == Loading) {
+        return m_loadJob->kill();
+    }
+
+    return m_extractJob->kill();
+}
+
+void BatchExtractJob::slotLoadingProgress(double progress)
+{
+    // Progress from LoadJob counts only for 50% of the BatchExtractJob's duration.
+    m_lastPercentage = static_cast<unsigned long>(50.0*progress);
+    setPercent(m_lastPercentage);
+}
+
+void BatchExtractJob::slotExtractProgress(double progress)
+{
+    // The 2nd 50% of the BatchExtractJob's duration comes from the ExtractJob.
+    setPercent(m_lastPercentage + static_cast<unsigned long>(50.0*progress));
+}
+
 void BatchExtractJob::slotLoadingFinished(KJob *job)
 {
     if (job->error()) {
@@ -378,11 +404,17 @@ void BatchExtractJob::slotLoadingFinished(KJob *job)
     Kerfuffle::ExtractionOptions options;
     options.setPreservePaths(m_preservePaths);
 
-    auto extractJob = archive()->extractFiles({}, m_destination, options);
-    if (extractJob) {
-        connect(extractJob, &KJob::result, this, &BatchExtractJob::emitResult);
-        connect(extractJob, &Kerfuffle::Job::userQuery, this, &BatchExtractJob::userQuery);
-        extractJob->start();
+    m_extractJob = archive()->extractFiles({}, m_destination, options);
+    if (m_extractJob) {
+        connect(m_extractJob, &KJob::result, this, &BatchExtractJob::emitResult);
+        connect(m_extractJob, &Kerfuffle::Job::userQuery, this, &BatchExtractJob::userQuery);
+        if (archiveInterface()->hasBatchExtractionProgress()) {
+            // The LoadJob is done, change slot and start setting the percentage from m_lastPercentage on.
+            disconnect(archiveInterface(), &ReadOnlyArchiveInterface::progress, this, &BatchExtractJob::slotLoadingProgress);
+            connect(archiveInterface(), &ReadOnlyArchiveInterface::progress, this, &BatchExtractJob::slotExtractProgress);
+        }
+        m_step = Extracting;
+        m_extractJob->start();
     } else {
         emitResult();
     }
